@@ -6,7 +6,7 @@ use strict;
 use warnings;
 no warnings 'redefine';
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 #use Smart::Comments;
 use Carp qw(carp confess);
@@ -272,6 +272,11 @@ sub as_gif {
     $self->_as_image('gif', @_);
 }
 
+sub as_svg {
+    my $self = shift;
+    $self->_as_image('svg', @_);
+}
+
 sub _as_image {
     my ($self, $type, $fname) = @_;
     my $dot = $self->as_dot;
@@ -768,7 +773,7 @@ UML::Class::Simple - Render simple UML class diagrams, by loading the code
 
 =head1 VERSION
 
-This document describes C<UML::Class::Simple> 0.20 released by 7 December 2014.
+This document describes C<UML::Class::Simple> 0.21 released by 17 December 2016.
 
 =head1 SYNOPSIS
 
@@ -929,6 +934,11 @@ C<classes_from_runtime> and C<classes_from_files>.
 Generate PNG image file when C<$filename> is given. It returns
 binary data when C<$filename> is not given.
 
+=item C<< $obj->as_svg($filename?) >>
+
+Generate SVG image file when C<$filename> is given. It returns
+binary data when C<$filename> is not given.
+
 =item C<< $obj->as_gif($filename?) >>
 
 Similar to C<as_png>, bug generate a GIF-format image. Note that, for many graphviz installations, C<gif> support is disabled by default. So you'll probably see the following error message:
@@ -1174,13 +1184,13 @@ I have a dream to keep sending out commit bits like Audrey Tang. ;-)
 
 =head1 AUTHORS
 
-Yichun "agentzh" Zhang (章亦春) C<< <agentzh@gmail.com> >>, CloudFlare Inc.
+Yichun "agentzh" Zhang (章亦春) C<< <agentzh@gmail.com> >>, OpenResty Inc.
 
 Maxim Zenin C<< <max@foggy.ru> >>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2014 by Yichun Zhang (章亦春), CloudFlare Inc.
+Copyright (c) 2006-2016 by Yichun Zhang (章亦春), OpenResty Inc.
 Copyright (c) 2007-2014 by Maxim Zenin.
 
 This library is free software; you can redistribute it and/or modify it under
